"""
Pydantic schema for FooterLarge05 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/footers/footer-large-05.tsx
Component Path: marketing/footers/footer-large-05
"""

from typing import Any

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import FooterNavCategory


class FooterLarge05Props(JSONFieldSchema):
    """Props for FooterLarge05"""

    nav_categories: list[FooterNavCategory] | None = Field(default=None, alias="navCategories")
    brand_name: str | None = Field(default=None, alias="brandName")
    copyright_text: str | None = Field(default=None, alias="copyrightText")
    logo_url: str | None = Field(default=None, alias="logoUrl")
    newsletter_config: Any | None = Field(default=None, alias="newsletterConfig")
