"""
Pydantic schema for TeamSectionImageGlass03 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/team-sections/team-section-image-glass-03.tsx
Component Path: marketing/team-sections/team-section-image-glass-03
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import T


class TeamSectionImageGlass03Props(JSONFieldSchema):
    """Props for TeamSectionImageGlass03 component."""

    eyebrow: str | None = Field(default=None, description="Small label above heading")
    headline: str | None = Field(default=None, description="Main heading")
    description: str | None = Field(default=None, description="Description text")
    primary_button_label: str | None = Field(
        default=None, alias="primaryButtonLabel", description="Primary button label"
    )
    primary_button_href: str | None = Field(default=None, alias="primaryButtonHref", description="Primary button href")
    secondary_button_label: str | None = Field(
        default=None, alias="secondaryButtonLabel", description="Secondary button label"
    )
    secondary_button_href: str | None = Field(
        default=None, alias="secondaryButtonHref", description="Secondary button href"
    )
    members: list[T] | None = Field(default=None, description="Array of team members")
