"""
Pydantic schema for TestimonialCard component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/testimonials/testimonial-card.tsx
Component Path: marketing/testimonials/testimonial-card
"""

from typing import Any

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class TestimonialCardProps(JSONFieldSchema):
    """Props for TestimonialCard component."""

    headline: str | None = Field(default=None)
    description: str | None = Field(default=None)
    testimonials: list[dict[str, Any]] | None = Field(default=None)
