"""
Pydantic schema for Step2EnterCodeManually component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: shared-assets/email-verification/step-2-enter-code-manually.tsx
Component Path: shared-assets/email-verification/step-2-enter-code-manually
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class Step2EnterCodeManuallyProps(JSONFieldSchema):
    """Props for Step2EnterCodeManually component."""

    headline: str | None = Field(default=None, description="Main headline text")
    description: str | None = Field(default=None, description="Description or body text")
    text: str | None = Field(default=None, description="Text content")
    primary_cta_text: str | None = Field(default=None, alias="primaryCtaText", description="Call-to-action button text")
    text2: str | None = Field(default=None, description="Text content")
    secondary_cta_text: str | None = Field(
        default=None, alias="secondaryCtaText", description="Call-to-action button text"
    )
    cta_text3: str | None = Field(default=None, alias="ctaText3", description="Call-to-action button text")
