"""
Pydantic schema for TestimonialGlassmorphicCards01 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/testimonials/testimonial-glassmorphic-cards-01.tsx
Component Path: marketing/testimonials/testimonial-glassmorphic-cards-01
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import ReviewItem, T


class TestimonialGlassmorphicCards01Props(JSONFieldSchema):
    """Props for TestimonialGlassmorphicCards01 component."""

    headline: str | None = Field(default=None, description="Section headline")
    subheading: str | None = Field(default=None, description="Section description")
    reviews: list[ReviewItem] | None = Field(default=None, description="Review items")
    primary_cta: T | None = Field(default=None, alias="primaryCta", description="Primary CTA button")
    secondary_cta: T | None = Field(default=None, alias="secondaryCta", description="Secondary CTA button")
