"""
Pydantic schema for TestimonialSimpleLeftAligned component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/testimonials/testimonial-simple-left-aligned.tsx
Component Path: marketing/testimonials/testimonial-simple-left-aligned
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class TestimonialSimpleLeftAlignedProps(JSONFieldSchema):
    """Props for TestimonialSimpleLeftAligned"""

    image_url: str | None = Field(default=None, alias="imageUrl", description="Author image URL")
    image_alt: str | None = Field(default=None, alias="imageAlt", description="Author image alt text")
    quote: str | None = Field(default=None, description="Quote text")
    author_name: str | None = Field(default=None, alias="authorName", description="Author name")
    author_title: str | None = Field(default=None, alias="authorTitle", description="Author title/role")
    rating: int | float | None = Field(default=None, description="Star rating (1-5)")
