"""
Application component schemas.

Mirrors lightwave-ui/src/components/application/.

These are application UI components:
- alerts: Alert/notification components
- app_navigation: App sidebar navigation
- breadcrumbs: Breadcrumb navigation
- calendar: Calendar components
- carousel: Carousel/slider components
- charts: Data visualization
- empty_state: Empty state displays
- modals: Modal dialogs
- notifications: Notification components
- pagination: Pagination controls
- progress_steps: Progress indicators
- table: Data tables
- tabs: Tab components

Usage:
    from lightwave.schema.pydantic.ui.components.application import (
        AlertProps,
        ModalProps,
        TableProps,
    )
"""

from lightwave.schema.pydantic.ui.components.application.alerts import AlertProps
from lightwave.schema.pydantic.ui.components.application.breadcrumbs import (
    BreadcrumbItem,
    BreadcrumbsProps,
)
from lightwave.schema.pydantic.ui.components.application.empty_state import (
    EmptyStateProps,
)
from lightwave.schema.pydantic.ui.components.application.modals import (
    ConfirmationModalProps,
    ModalProps,
)
from lightwave.schema.pydantic.ui.components.application.notifications import (
    NotificationProps,
)
from lightwave.schema.pydantic.ui.components.application.pagination import (
    PaginationProps,
)
from lightwave.schema.pydantic.ui.components.application.progress_steps import (
    ProgressStep,
    ProgressStepsProps,
)
from lightwave.schema.pydantic.ui.components.application.table import (
    TableColumn,
    TableProps,
)
from lightwave.schema.pydantic.ui.components.application.tabs import TabItem, TabsProps

__all__ = [
    # Alerts
    "AlertProps",
    # Modals
    "ModalProps",
    "ConfirmationModalProps",
    # Table
    "TableColumn",
    "TableProps",
    # Tabs
    "TabItem",
    "TabsProps",
    # Pagination
    "PaginationProps",
    # Breadcrumbs
    "BreadcrumbItem",
    "BreadcrumbsProps",
    # Empty State
    "EmptyStateProps",
    # Notifications
    "NotificationProps",
    # Progress
    "ProgressStep",
    "ProgressStepsProps",
]
