"""
Pydantic schema for TestimonialSocialCards01 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/testimonials/testimonial-social-cards-01.tsx
Component Path: marketing/testimonials/testimonial-social-cards-01
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import T


class TestimonialSocialCards01Props(JSONFieldSchema):
    """Props for TestimonialSocialCards01"""

    headline: str | None = Field(default=None)
    description: str | None = Field(default=None)
    testimonials: list[T] | None = Field(default=None)
