"""
Pydantic schema for FooterLarge06Brand component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/footers/footer-large-06-brand.tsx
Component Path: marketing/footers/footer-large-06-brand
"""

from typing import Any

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import FooterNavCategory, FooterSocialItem


class FooterLarge06BrandProps(JSONFieldSchema):
    """Props for FooterLarge06Brand component."""

    logo: Any | None = Field(default=None, alias="Logo", description="Logo component")
    brand_name: str | None = Field(default=None, alias="brandName", description="Brand name for copyright")
    brand_description: str | None = Field(default=None, alias="brandDescription", description="Brand description text")
    nav_categories: list[FooterNavCategory] | None = Field(
        default=None, alias="navCategories", description="Navigation categories"
    )
    social_links: list[FooterSocialItem] | None = Field(
        default=None, alias="socialLinks", description="Social media links"
    )
    newsletter_heading: str | None = Field(default=None, alias="newsletterHeading", description="Newsletter heading")
    newsletter_description: str | None = Field(
        default=None, alias="newsletterDescription", description="Newsletter description"
    )
    copyright_text: str | None = Field(default=None, alias="copyrightText", description="Copyright text override")
    show_rating_badge: bool | None = Field(default=None, alias="showRatingBadge", description="Show rating badge")
