"""
Pydantic schema for MetricsSimpleWithActions01 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/metrics/metrics-simple-with-actions-01.tsx
Component Path: marketing/metrics/metrics-simple-with-actions-01
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import MetricItem


class MetricsSimpleWithActions01Props(JSONFieldSchema):
    """Props for MetricsSimpleWithActions01 component."""

    headline: str | None = Field(default=None, description="Main heading")
    description: str | None = Field(default=None, description="Description text")
    demo_button_label: str | None = Field(default=None, alias="demoButtonLabel", description="Demo button label")
    demo_button_href: str | None = Field(default=None, alias="demoButtonHref", description="Demo button href")
    primary_button_label: str | None = Field(
        default=None, alias="primaryButtonLabel", description="Primary button label"
    )
    primary_button_href: str | None = Field(default=None, alias="primaryButtonHref", description="Primary button href")
    items: list[MetricItem] | None = Field(default=None, description="Array of metric items")
