"""
Pydantic schema for Icon component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: base/icons/Icon.tsx
Component Path: base/icons/Icon
"""

from typing import Any

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import T


class IconProps(JSONFieldSchema):
    """Props for Icon component."""

    icon: T
    size: Any | None = Field(default=None)
    class_name: str | None = Field(default=None, alias="className")
    aria_label: str | None = Field(default=None, alias="aria-label")
