"""
Pydantic schema for ThemeProvider component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: providers/ThemeProvider.tsx
Component Path: providers/ThemeProvider
"""

from typing import Any

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import T


class ThemeProviderProps(JSONFieldSchema):
    """Props for ThemeProvider component."""

    children: str | dict[str, Any] | None
    default_theme: T | None = Field(default=None, alias="defaultTheme")
