"""
Provider component schemas.

Mirrors lightwave-ui/src/components/providers/.

These are React context providers (theme, auth, etc.).
Generally these don't have props schemas as they're
purely implementation-side.
"""

# Placeholder - provider props are typically React-internal

__all__: list[str] = []
