"""
Pydantic schema for FooterLarge01 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/footers/footer-large-01.tsx
Component Path: marketing/footers/footer-large-01
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import FooterNavCategory


class FooterLarge01Props(JSONFieldSchema):
    """Props for FooterLarge01"""

    nav_categories: list[FooterNavCategory] | None = Field(
        default=None, alias="navCategories", description="Navigation categories to display"
    )
    brand_name: str | None = Field(default=None, alias="brandName", description="Company name for copyright")
    copyright_text: str | None = Field(
        default=None, alias="copyrightText", description="Custom copyright text (overrides auto-generated)"
    )
    logo_url: str | None = Field(default=None, alias="logoUrl", description="Logo URL for image-based logo")
