"""
Pydantic schema for HeroSplitImage06 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/header-section/hero-split-image-06.tsx
Component Path: marketing/header-section/hero-split-image-06
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class HeroSplitImage06Props(JSONFieldSchema):
    """Props for HeroSplitImage06 component."""

    image_alt: str | None = Field(default=None, alias="imageAlt", description="alt attribute value")
    image_alt2: str | None = Field(default=None, alias="imageAlt2", description="alt attribute value")
    headline: str | None = Field(default=None, description="Main headline text")
    description: str | None = Field(default=None, description="Description or body text")
    email_placeholder: str | None = Field(
        default=None, alias="emailPlaceholder", description="placeholder attribute value"
    )
    text: str | None = Field(default=None, description="Text content")
    link_text: str | None = Field(default=None, alias="linkText", description="Text content")
    cta_text: str | None = Field(default=None, alias="ctaText", description="Call-to-action button text")
    image_alt3: str | None = Field(default=None, alias="imageAlt3", description="alt attribute value")
