"""
Base component schemas.

Mirrors lightwave-ui/src/components/base/.

These are foundational components used throughout the UI:
- buttons: Button components
- checkbox: Checkbox components
- dropdown: Dropdown/select components
- form: Form wrapper components
- input: Input field components
- slider: Slider components
- tooltip: Tooltip components

Usage:
    from lightwave.schema.pydantic.ui.components.base import (
        ButtonProps,
        InputProps,
        CheckboxProps,
    )
"""

from lightwave.schema.pydantic.ui.components.base.buttons import ButtonProps
from lightwave.schema.pydantic.ui.components.base.checkbox import CheckboxProps
from lightwave.schema.pydantic.ui.components.base.dropdown import DropdownProps
from lightwave.schema.pydantic.ui.components.base.form import FormProps
from lightwave.schema.pydantic.ui.components.base.input import InputProps
from lightwave.schema.pydantic.ui.components.base.slider import SliderProps
from lightwave.schema.pydantic.ui.components.base.tooltip import TooltipProps

__all__ = [
    "ButtonProps",
    "CheckboxProps",
    "DropdownProps",
    "InputProps",
    "FormProps",
    "SliderProps",
    "TooltipProps",
]
