"""
Pydantic schema for HeroIphoneMockup01 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/header-section/hero-iphone-mockup-01.tsx
Component Path: marketing/header-section/hero-iphone-mockup-01
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class HeroIPhoneMockup01Props(JSONFieldSchema):
    """Props for HeroIPhoneMockup01 component."""

    image_alt: str | None = Field(default=None, alias="imageAlt", description="alt attribute value")
    image_alt2: str | None = Field(default=None, alias="imageAlt2", description="alt attribute value")
    addon_text: str | None = Field(default=None, alias="addonText", description="Badge label text")
    badge_text: str | None = Field(default=None, alias="badgeText", description="Badge label text")
    addon_text2: str | None = Field(default=None, alias="addonText2", description="Badge label text")
    badge_text2: str | None = Field(default=None, alias="badgeText2", description="Badge label text")
    headline: str | None = Field(default=None, description="Main headline text")
    description: str | None = Field(default=None, description="Description or body text")
