"""
Pydantic schema for HeaderSpaceBetweenButtons component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/header-section/header-space-between-buttons.tsx
Component Path: marketing/header-section/header-space-between-buttons
"""

from typing import Any, Literal

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class HeaderSpaceBetweenButtonsProps(JSONFieldSchema):
    """Props for HeaderSpaceBetweenButtons component."""

    eyebrow: str | None = Field(default=None, description="Eyebrow/label text")
    headline: str | None = Field(default=None, description="Main headline text")
    description: str | None = Field(default=None, description="Description or body text")
    primary_cta_text: str | None = Field(
        default=None, alias="primaryCtaText", description="Primary call-to-action button text (hide button if empty)"
    )
    secondary_cta_text: str | None = Field(
        default=None,
        alias="secondaryCtaText",
        description="Secondary call-to-action button text (hide button if empty)",
    )
    header_props: Any | None = Field(
        default=None, alias="headerProps", description="Props passed to embedded Header component"
    )
    show_header: bool | None = Field(
        default=None,
        alias="showHeader",
        description="Show embedded floating header (default: true). Set to false to use separate header island.",
    )
    header_variant: Literal["header-default", "header-minimal"] | None = Field(
        default=None, alias="headerVariant", description='Header variant to use (default: "header-default").'
    )
