"""
Pydantic schema for HeroIphoneMockup04 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/header-section/hero-iphone-mockup-04.tsx
Component Path: marketing/header-section/hero-iphone-mockup-04
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class HeroIPhoneMockup04Props(JSONFieldSchema):
    """Props for HeroIPhoneMockup04 component."""

    image_alt: str | None = Field(default=None, alias="imageAlt", description="alt attribute value")
    image_alt2: str | None = Field(default=None, alias="imageAlt2", description="alt attribute value")
    image_alt3: str | None = Field(default=None, alias="imageAlt3", description="alt attribute value")
    image_alt4: str | None = Field(default=None, alias="imageAlt4", description="alt attribute value")
    image_alt5: str | None = Field(default=None, alias="imageAlt5", description="alt attribute value")
    description: str | None = Field(default=None, description="Description or body text")
    image_alt6: str | None = Field(default=None, alias="imageAlt6", description="alt attribute value")
    image_alt7: str | None = Field(default=None, alias="imageAlt7", description="alt attribute value")
    headline: str | None = Field(default=None, description="Main headline text")
    description2: str | None = Field(default=None, description="Description or body text")
    primary_cta_text: str | None = Field(default=None, alias="primaryCtaText", description="Call-to-action button text")
    secondary_cta_text: str | None = Field(
        default=None, alias="secondaryCtaText", description="Call-to-action button text"
    )
    image_alt8: str | None = Field(default=None, alias="imageAlt8", description="alt attribute value")
    text: str | None = Field(default=None, description="Text content")
    description3: str | None = Field(default=None, description="Description or body text")
    description4: str | None = Field(default=None, description="Description or body text")
    image_alt9: str | None = Field(default=None, alias="imageAlt9", description="alt attribute value")
    text2: str | None = Field(default=None, description="Text content")
    description5: str | None = Field(default=None, description="Description or body text")
    text3: str | None = Field(default=None, description="Text content")
    description6: str | None = Field(default=None, description="Description or body text")
    image_alt10: str | None = Field(default=None, alias="imageAlt10", description="alt attribute value")
    text4: str | None = Field(default=None, description="Text content")
    description7: str | None = Field(default=None, description="Description or body text")
    text5: str | None = Field(default=None, description="Text content")
    image_alt11: str | None = Field(default=None, alias="imageAlt11", description="alt attribute value")
    text6: str | None = Field(default=None, description="Text content")
    description8: str | None = Field(default=None, description="Description or body text")
    text7: str | None = Field(default=None, description="Text content")
