"""
Faq island prop schemas.

Auto-generated from packages/lightwave-ui/src/islands/faq-registry.tsx
Generated: 2026-02-02

Islands are React components hydrated on the client. These schemas define
the props that Django passes to the React island via JSON serialization.
"""

from pydantic import ConfigDict

from lightwave.schema.pydantic.core.base import LightwaveBaseSchema


class FaqItemsItem(LightwaveBaseSchema):
    """Nested item type for items."""

    question: str = None
    answer: str = None

    model_config = ConfigDict(
        populate_by_name=True,
        extra="forbid",
    )


class BaseFaqProps(LightwaveBaseSchema):
    """
    Base props that all faq variants should support.

    Source: packages/lightwave-ui/src/islands/faq-registry.tsx
    """

    headline: str | None = None
    description: str | None = None
    items: list[FaqItemsItem] | None = None

    model_config = ConfigDict(
        populate_by_name=True,
        extra="forbid",
    )


FAQ_VARIANTS = ["accordion-01", "accordion-01-brand", "accordion-03", "simple-01", "simple-02-brand"]

__all__ = ["BaseFaqProps", "FAQ_VARIANTS"]
