"""
Pydantic schema for SelectNative component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: base/select/select-native.tsx
Component Path: base/select/select-native
"""

from typing import Any

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class NativeSelectProps(JSONFieldSchema):
    """Props for NativeSelect component."""

    label: str | None = Field(default=None)
    hint: str | None = Field(default=None)
    select_class_name: str | None = Field(default=None, alias="selectClassName")
    options: list[dict[str, Any]]
