"""
Footer island prop schemas.

Auto-generated from packages/lightwave-ui/src/islands/footer-registry.tsx
Generated: 2026-02-02

Islands are React components hydrated on the client. These schemas define
the props that Django passes to the React island via JSON serialization.
"""

from pydantic import ConfigDict, Field

from lightwave.schema.pydantic.core.base import LightwaveBaseSchema


class BaseFooterProps(LightwaveBaseSchema):
    """
    Base props that all footer variants should support.

    Source: packages/lightwave-ui/src/islands/footer-registry.tsx
    """

    brand_name: str | None = Field(None, serialization_alias="brandName")
    logo_url: str | None = Field(None, serialization_alias="logoUrl")
    logo_minimal_url: str | None = Field(None, serialization_alias="logoMinimalUrl")
    logo: str | None = None
    links: list[str] | None = None
    link_groups: list[str] | None = Field(None, serialization_alias="linkGroups")
    social_links: list[str] | None = Field(None, serialization_alias="socialLinks")
    copyright_text: str | None = Field(None, serialization_alias="copyrightText")
    copyright_year: str | None = Field(None, serialization_alias="copyrightYear")
    privacy_url: str | None = Field(None, serialization_alias="privacyUrl")
    terms_url: str | None = Field(None, serialization_alias="termsUrl")
    newsletter_enabled: bool | None = Field(None, serialization_alias="newsletterEnabled")
    newsletter_action: str | None = Field(None, serialization_alias="newsletterAction")
    newsletter_placeholder: str | None = Field(None, serialization_alias="newsletterPlaceholder")
    cta_title: str | None = Field(None, serialization_alias="ctaTitle")
    cta_description: str | None = Field(None, serialization_alias="ctaDescription")
    cta_button_text: str | None = Field(None, serialization_alias="ctaButtonText")
    cta_button_url: str | None = Field(None, serialization_alias="ctaButtonUrl")
    tagline: str | None = None

    model_config = ConfigDict(
        populate_by_name=True,
        extra="forbid",
    )


FOOTER_VARIANTS = [
    "footer-small-01",
    "footer-small-02",
    "footer-small-03",
    "footer-small-04",
    "footer-large-01",
    "footer-large-02",
    "footer-large-03",
    "footer-large-04",
    "footer-large-05",
    "footer-large-06",
    "footer-large-07",
    "footer-large-08",
    "footer-large-15",
]

__all__ = ["BaseFooterProps", "FOOTER_VARIANTS"]
