"""
Metrics island prop schemas.

Auto-generated from packages/lightwave-ui/src/islands/metrics-registry.tsx
Generated: 2026-02-02

Islands are React components hydrated on the client. These schemas define
the props that Django passes to the React island via JSON serialization.
"""

from pydantic import ConfigDict

from lightwave.schema.pydantic.core.base import LightwaveBaseSchema


class MetricsMetricsItem(LightwaveBaseSchema):
    """Nested item type for metrics."""

    label: str = None
    value: str = None
    key: str = None

    model_config = ConfigDict(
        populate_by_name=True,
        extra="forbid",
    )


class BaseMetricsProps(LightwaveBaseSchema):
    """
    Base props that all metrics variants should support.

    Source: packages/lightwave-ui/src/islands/metrics-registry.tsx
    """

    eyebrow: str | None = None
    headline: str | None = None
    description: str | None = None
    metrics: list[MetricsMetricsItem] | None = None

    model_config = ConfigDict(
        populate_by_name=True,
        extra="forbid",
    )


METRICS_VARIANTS = [
    "card-brand-dark",
    "card-gray-light",
    "image-with-cards-01",
    "image-with-cards-02",
    "simple-accent-line",
    "simple-centered-text",
    "simple-with-actions-01",
    "simple-with-actions-02",
]

__all__ = ["BaseMetricsProps", "METRICS_VARIANTS"]
