"""
Pydantic schema for MetricsImageWithCards02 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/metrics/metrics-image-with-cards-02.tsx
Component Path: marketing/metrics/metrics-image-with-cards-02
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import MetricItem


class MetricsImageWithCards02Props(JSONFieldSchema):
    """Props for MetricsImageWithCards02 component."""

    eyebrow: str | None = Field(default=None, description="Small label above heading")
    headline: str | None = Field(default=None, description="Main heading")
    description: str | None = Field(default=None, description="Description text")
    demo_button_label: str | None = Field(default=None, alias="demoButtonLabel", description="Demo button label")
    demo_button_href: str | None = Field(default=None, alias="demoButtonHref", description="Demo button href")
    primary_button_label: str | None = Field(
        default=None, alias="primaryButtonLabel", description="Primary button label"
    )
    primary_button_href: str | None = Field(default=None, alias="primaryButtonHref", description="Primary button href")
    background_image_url: str | None = Field(
        default=None, alias="backgroundImageUrl", description="Background image URL"
    )
    items: list[MetricItem] | None = Field(default=None, description="Array of metric items")
