"""
Pydantic schema for TeamSectionImageCard01 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/team-sections/team-section-image-card-01.tsx
Component Path: marketing/team-sections/team-section-image-card-01
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import T


class TeamSectionImageCard01Props(JSONFieldSchema):
    """Props for TeamSectionImageCard01 component."""

    label: str | None = Field(default=None, description="Small label above heading")
    heading: str | None = Field(default=None, description="Main heading")
    description: str | None = Field(default=None, description="Description text")
    primary_label: str | None = Field(default=None, alias="primaryLabel", description="Primary CTA button label")
    primary_href: str | None = Field(default=None, alias="primaryHref", description="Primary CTA button href")
    secondary_label: str | None = Field(default=None, alias="secondaryLabel", description="Secondary CTA button label")
    secondary_href: str | None = Field(default=None, alias="secondaryHref", description="Secondary CTA button href")
    members: list[T] | None = Field(default=None, description="Array of team members")
    class_name: str | None = Field(
        default=None,
        alias="className",
        description="Additional CSS classes for the section (use to override background, etc.)",
    )
