"""
Pydantic schema for ProgressSteps component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: shared-assets/signup/progress-steps.tsx
Component Path: shared-assets/signup/progress-steps
"""

from typing import Literal

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import Item


class ProgressIconsCenteredProps(JSONFieldSchema):
    """Props for ProgressIconsCentered component."""

    size: Literal["md", "sm"] | None = Field(default=None)
    connector: bool | None = Field(default=None)
    items: list[Item]
