"""
Gallery island prop schemas.

Auto-generated from packages/lightwave-ui/src/islands/gallery-registry.tsx
Generated: 2026-02-02

Islands are React components hydrated on the client. These schemas define
the props that Django passes to the React island via JSON serialization.
"""

from pydantic import ConfigDict, Field

from lightwave.schema.pydantic.core.base import LightwaveBaseSchema


class GalleryItemsItem(LightwaveBaseSchema):
    """Nested item type for items."""

    title: str | None = None
    image_url: str | None = Field(None, serialization_alias="imageUrl")
    href: str | None = None
    key: str = None

    model_config = ConfigDict(
        populate_by_name=True,
        extra="forbid",
    )


class BaseGalleryProps(LightwaveBaseSchema):
    """
    Base props that all gallery variants should support.

    Source: packages/lightwave-ui/src/islands/gallery-registry.tsx
    """

    eyebrow: str | None = None
    headline: str | None = None
    description: str | None = None
    items: list[GalleryItemsItem] | None = None

    model_config = ConfigDict(
        populate_by_name=True,
        extra="forbid",
    )


GALLERY_VARIANTS = ["content-large-image-01", "content-alternative-01", "content-split-image-01"]

__all__ = ["BaseGalleryProps", "GALLERY_VARIANTS"]
