"""
Pydantic schema for PricingSectionSimpleCards01 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/pricing-sections/pricing-section-simple-cards-01.tsx
Component Path: marketing/pricing-sections/pricing-section-simple-cards-01
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import PlanItem


class PricingSectionSimpleCards01Props(JSONFieldSchema):
    """Props for PricingSectionSimpleCards01"""

    plans: list[PlanItem] | None = Field(default=None, description="Pricing plans")
