"""
Marketing component schemas.

Mirrors lightwave-ui/src/components/marketing/ structure.

Each file corresponds to a folder in TypeScript:
- header_navigation.py → header-navigation/
- header_section.py → header-section/
- features.py → features/
- testimonials.py → testimonials/
- cta.py → cta/
- faq.py → faq/
- pricing_sections.py → pricing-sections/
- social_proof.py → social-proof/
- footers.py → footers/
- blog.py → blog/
- metrics.py → metrics/
- team_sections.py → team-sections/
- contact.py → contact/
- banners.py → banners/
- careers.py → careers/
- content.py → content/
- newsletter_cta.py → newsletter-cta/

Usage:
    from lightwave.schema.pydantic.ui.components.marketing import (
        HeroSimpleText01Props,
        TestimonialsSectionProps,
    )
"""

from lightwave.schema.pydantic.ui.components.marketing.banners import (
    BannerDualActionBrandFullWidthProps,
    BannerSectionProps,
    BannerSingleActionBrandFullWidthProps,
    BannerSingleActionBrandProps,
    BannerSlimBrandFullWidthProps,
    BannerSlimDefaultProps,
)
from lightwave.schema.pydantic.ui.components.marketing.blog import (
    ArticleItem,
    BlogHeaderFeaturedPost02Props,
    BlogSectionCarouselLayout02Props,
    BlogSectionProps,
    BlogSectionSimpleLeftAligned01Props,
)
from lightwave.schema.pydantic.ui.components.marketing.careers import (
    CareersCard01Props,
    CareersSectionProps,
    JobItem,
)
from lightwave.schema.pydantic.ui.components.marketing.contact import (
    ContactCenteredMapProps,
    ContactSectionProps,
    ContactSimpleLinks01Props,
)
from lightwave.schema.pydantic.ui.components.marketing.content import (
    ContentLargeImage01Props,
    ContentSectionProps,
    ContentSectionRichText01Props,
    ContentSectionSimple01Props,
    ContentSectionSplitImage01Props,
    ContentSimpleProps,
)
from lightwave.schema.pydantic.ui.components.marketing.cta import (
    CTAAbstractImagesBrandProps,
    CTASectionProps,
    CTASimpleLogos02Props,
    CTASplitImage01Props,
    CTASplitImageQuote01Props,
)
from lightwave.schema.pydantic.ui.components.marketing.faq import (
    FAQAccordion01Props,
    FAQItem,
    FAQSectionProps,
    FAQSimple02Props,
)
from lightwave.schema.pydantic.ui.components.marketing.features import (
    FeatureItem,
    FeaturesAlternatingLayout01Props,
    FeaturesCenterMockup01Props,
    FeaturesIconCards02Props,
    FeaturesIconsAndImage01Props,
    FeaturesIconsAndMockup01Props,
    FeaturesIntegrationsIcons01Props,
    FeaturesSectionProps,
    FeaturesSimpleIcons04Props,
    FeaturesTabsMockup01Props,
)
from lightwave.schema.pydantic.ui.components.marketing.footers import (
    FooterLarge03Props,
    FooterLarge07Props,
    FooterLarge15BrandProps,
    FooterProps,
    FooterSmall02Props,
    FooterSmall03Props,
)
from lightwave.schema.pydantic.ui.components.marketing.header_navigation import (
    HeaderNavItem,
    HeaderProps,
)
from lightwave.schema.pydantic.ui.components.marketing.header_section import (
    HeaderSectionProps,
    HeroAbstractAngles04Props,
    HeroCardMockup01Props,
    HeroIphoneMockup02Props,
    HeroScreenMockup02Props,
    HeroSimpleText01Props,
)
from lightwave.schema.pydantic.ui.components.marketing.metrics import (
    MetricItem,
    MetricsImageWithCards01Props,
    MetricsSectionProps,
    MetricsSimpleAccentLineProps,
)
from lightwave.schema.pydantic.ui.components.marketing.newsletter_cta import (
    NewsletterCTAProps,
)
from lightwave.schema.pydantic.ui.components.marketing.pricing_sections import (
    PricingAbstractAnglesProps,
    PricingPrimaryCardSimpleProps,
    PricingSectionFeaturedCards01Props,
    PricingSectionProps,
    PricingSimpleAccentLineProps,
    PricingTierProps,
)
from lightwave.schema.pydantic.ui.components.marketing.social_proof import (
    LogoItem,
    SocialProofCardBrandProps,
    SocialProofPressMentionsProps,
    SocialProofSectionProps,
)
from lightwave.schema.pydantic.ui.components.marketing.team_sections import (
    TeamMemberItem,
    TeamSectionImageCollage01Props,
    TeamSectionProps,
)
from lightwave.schema.pydantic.ui.components.marketing.testimonials import (
    ReviewProps,
    TestimonialGlassmorphicCards01Props,
    TestimonialProps,
    TestimonialsSectionProps,
)

__all__ = [
    # Header Navigation
    "HeaderProps",
    "HeaderNavItem",
    # Header Section (Heroes)
    "HeaderSectionProps",
    "HeroSimpleText01Props",
    "HeroScreenMockup02Props",
    "HeroCardMockup01Props",
    "HeroIphoneMockup02Props",
    "HeroAbstractAngles04Props",
    # Features
    "FeaturesSectionProps",
    "FeatureItem",
    "FeaturesSimpleIcons04Props",
    "FeaturesIconsAndMockup01Props",
    "FeaturesTabsMockup01Props",
    "FeaturesAlternatingLayout01Props",
    "FeaturesCenterMockup01Props",
    "FeaturesIconsAndImage01Props",
    "FeaturesIntegrationsIcons01Props",
    "FeaturesIconCards02Props",
    # Testimonials
    "TestimonialsSectionProps",
    "TestimonialProps",
    "ReviewProps",
    "TestimonialGlassmorphicCards01Props",
    # CTA
    "CTASectionProps",
    "CTASplitImage01Props",
    "CTASplitImageQuote01Props",
    "CTAAbstractImagesBrandProps",
    "CTASimpleLogos02Props",
    # FAQ
    "FAQSectionProps",
    "FAQItem",
    "FAQAccordion01Props",
    "FAQSimple02Props",
    # Pricing
    "PricingSectionProps",
    "PricingTierProps",
    "PricingSectionFeaturedCards01Props",
    "PricingPrimaryCardSimpleProps",
    "PricingSimpleAccentLineProps",
    "PricingAbstractAnglesProps",
    # Social Proof
    "SocialProofSectionProps",
    "LogoItem",
    "SocialProofCardBrandProps",
    "SocialProofPressMentionsProps",
    # Footers
    "FooterProps",
    "FooterLarge03Props",
    "FooterLarge07Props",
    "FooterLarge15BrandProps",
    "FooterSmall02Props",
    "FooterSmall03Props",
    # Blog
    "BlogSectionProps",
    "ArticleItem",
    "BlogSectionSimpleLeftAligned01Props",
    "BlogSectionCarouselLayout02Props",
    "BlogHeaderFeaturedPost02Props",
    # Metrics
    "MetricsSectionProps",
    "MetricItem",
    "MetricsSimpleAccentLineProps",
    "MetricsImageWithCards01Props",
    # Team
    "TeamSectionProps",
    "TeamMemberItem",
    "TeamSectionImageCollage01Props",
    # Contact
    "ContactSectionProps",
    "ContactSimpleLinks01Props",
    "ContactCenteredMapProps",
    # Banners
    "BannerSectionProps",
    "BannerSlimDefaultProps",
    "BannerSlimBrandFullWidthProps",
    "BannerSingleActionBrandProps",
    "BannerSingleActionBrandFullWidthProps",
    "BannerDualActionBrandFullWidthProps",
    # Careers
    "CareersSectionProps",
    "JobItem",
    "CareersCard01Props",
    # Content
    "ContentSectionProps",
    "ContentSimpleProps",
    "ContentSectionSimple01Props",
    "ContentSectionRichText01Props",
    "ContentLargeImage01Props",
    "ContentSectionSplitImage01Props",
    # Newsletter
    "NewsletterCTAProps",
]
