"""
Page component schemas.

Mirrors lightwave-ui/src/pages/.

These are full page component schemas (rarely used directly
as pages are typically composed of section components).
"""

# Placeholder - page schemas added as needed

__all__: list[str] = []
