"""
Pydantic schema for TestimonialAbstractImage component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/testimonials/testimonial-abstract-image.tsx
Component Path: marketing/testimonials/testimonial-abstract-image
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import GalleryImage, ReviewItem


class TestimonialAbstractImageProps(JSONFieldSchema):
    """Props for TestimonialAbstractImage"""

    reviews: list[ReviewItem] | None = Field(default=None, description="Review items for carousel")
    gallery_images: list[GalleryImage] | None = Field(default=None, alias="galleryImages", description="Gallery images")
