"""
Store/state schemas.

Mirrors lightwave-ui/src/stores/.

These define state shapes for Zustand stores.
Generally client-side only, but can be useful for SSR hydration.
"""

# Placeholder - store state schemas added as needed

__all__: list[str] = []
