"""
Pydantic schema for HeroSimpleText02 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/header-section/hero-simple-text-02.tsx
Component Path: marketing/header-section/hero-simple-text-02
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class HeroSimpleText02Props(JSONFieldSchema):
    """Props for HeroSimpleText02 component."""

    image_alt: str | None = Field(default=None, alias="imageAlt", description="alt attribute value")
    image_alt2: str | None = Field(default=None, alias="imageAlt2", description="alt attribute value")
    headline: str | None = Field(default=None, description="Main headline text")
    text: str | None = Field(default=None, description="Text content")
    headline2: str | None = Field(default=None, description="Main headline text")
    description: str | None = Field(default=None, description="Description or body text")
    primary_cta_text: str | None = Field(default=None, alias="primaryCtaText", description="Call-to-action button text")
    secondary_cta_text: str | None = Field(
        default=None, alias="secondaryCtaText", description="Call-to-action button text"
    )
    image_alt3: str | None = Field(default=None, alias="imageAlt3", description="alt attribute value")
