"""
Pydantic schema for HeroScreenMockup02 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/header-section/hero-screen-mockup-02.tsx
Component Path: marketing/header-section/hero-screen-mockup-02
"""

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema


class HeroScreenMockup02Props(JSONFieldSchema):
    """Props for HeroScreenMockup02 component."""

    image_alt: str | None = Field(default=None, alias="imageAlt", description="alt attribute value")
    image_alt2: str | None = Field(default=None, alias="imageAlt2", description="alt attribute value")
    headline: str | None = Field(default=None, description="Main headline text")
    description: str | None = Field(default=None, description="Description or body text")
    primary_cta_text: str | None = Field(default=None, alias="primaryCtaText", description="Call-to-action button text")
    secondary_cta_text: str | None = Field(
        default=None, alias="secondaryCtaText", description="Call-to-action button text"
    )
    description2: str | None = Field(default=None, description="Description or body text")
    image_alt3: str | None = Field(default=None, alias="imageAlt3", description="alt attribute value")
    image_alt4: str | None = Field(default=None, alias="imageAlt4", description="alt attribute value")
    image_alt5: str | None = Field(default=None, alias="imageAlt5", description="alt attribute value")
    image_alt6: str | None = Field(default=None, alias="imageAlt6", description="alt attribute value")
    image_alt7: str | None = Field(default=None, alias="imageAlt7", description="alt attribute value")
    image_alt8: str | None = Field(default=None, alias="imageAlt8", description="alt attribute value")
    image_alt9: str | None = Field(default=None, alias="imageAlt9", description="alt attribute value")
    image_alt10: str | None = Field(default=None, alias="imageAlt10", description="alt attribute value")
    image_alt11: str | None = Field(default=None, alias="imageAlt11", description="alt attribute value")
    image_alt12: str | None = Field(default=None, alias="imageAlt12", description="alt attribute value")
    image_alt13: str | None = Field(default=None, alias="imageAlt13", description="alt attribute value")
    image_alt14: str | None = Field(default=None, alias="imageAlt14", description="alt attribute value")
    image_alt15: str | None = Field(default=None, alias="imageAlt15", description="alt attribute value")
    image_alt16: str | None = Field(default=None, alias="imageAlt16", description="alt attribute value")
    description3: str | None = Field(default=None, description="Description or body text")
    image_alt17: str | None = Field(default=None, alias="imageAlt17", description="alt attribute value")
    image_alt18: str | None = Field(default=None, alias="imageAlt18", description="alt attribute value")
    image_alt19: str | None = Field(default=None, alias="imageAlt19", description="alt attribute value")
    image_alt20: str | None = Field(default=None, alias="imageAlt20", description="alt attribute value")
    image_alt21: str | None = Field(default=None, alias="imageAlt21", description="alt attribute value")
    image_alt22: str | None = Field(default=None, alias="imageAlt22", description="alt attribute value")
    image_alt23: str | None = Field(default=None, alias="imageAlt23", description="alt attribute value")
    image_alt24: str | None = Field(default=None, alias="imageAlt24", description="alt attribute value")
    image_alt25: str | None = Field(default=None, alias="imageAlt25", description="alt attribute value")
    image_alt26: str | None = Field(default=None, alias="imageAlt26", description="alt attribute value")
    image_alt27: str | None = Field(default=None, alias="imageAlt27", description="alt attribute value")
    image_alt28: str | None = Field(default=None, alias="imageAlt28", description="alt attribute value")
