"""
Pydantic schema for FooterLarge07 component.

AUTO-GENERATED FROM ui-manifest.json - DO NOT EDIT MANUALLY
Source: marketing/footers/footer-large-07.tsx
Component Path: marketing/footers/footer-large-07
"""

from typing import Any

from pydantic import Field

from lightwave.schema.pydantic.core.base import JSONFieldSchema

from ._types import FooterSocialLink, NavItem


class FooterLarge07Props(JSONFieldSchema):
    """Props for FooterLarge07"""

    nav_items: list[NavItem] | None = Field(default=None, alias="navItems")
    brand_name: str | None = Field(default=None, alias="brandName")
    brand_description: str | None = Field(default=None, alias="brandDescription")
    copyright_text: str | None = Field(default=None, alias="copyrightText")
    logo_url: str | None = Field(default=None, alias="logoUrl")
    social_links: list[FooterSocialLink] | None = Field(default=None, alias="socialLinks")
    app_store_config: Any | None = Field(default=None, alias="appStoreConfig")
